@@ -59,11 +59,11 @@ KIO::UDSEntry createUDSEntryForTag(const QString& tag)
     uds.insert(KIO::UDSEntry::UDS_NAME, tag);
     uds.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, tag);
     uds.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1("inode/directory"));
+    uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/directory"));
     uds.insert(KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n("Tag"));
     uds.insert(KIO::UDSEntry::UDS_ACCESS, 0700);
     uds.insert(KIO::UDSEntry::UDS_USER, KUser().loginName());
-    uds.insert(KIO::UDSEntry::UDS_ICON_NAME, QLatin1String("tag"));
+    uds.insert(KIO::UDSEntry::UDS_ICON_NAME, QStringLiteral("tag"));
 
     return uds;
 }
@@ -97,9 +97,8 @@ void TagsProtocol::listDir(const QUrl& url)
 
     case TagUrl: {
         Query q;
-        q.addType(QLatin1String("File"));
-        q.setTerm(Term(QLatin1String("tag"), tag));
         q.setSortingOption(Query::SortNone);
+        q.setSearchString(QStringLiteral("tag=\"%1\"").arg(tag));
 
         ResultIterator it = q.exec();
         while (it.next()) {
@@ -156,12 +155,12 @@ void TagsProtocol::stat(const QUrl& url)
         uds.insert(KIO::UDSEntry::UDS_ACCESS, 0700);
         uds.insert(KIO::UDSEntry::UDS_USER, KUser().loginName());
         uds.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-        uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1("inode/directory"));
+        uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/directory"));
 
-        uds.insert(KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QLatin1String("tag"));
+        uds.insert(KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QStringLiteral("tag"));
         uds.insert(KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n("Tag"));
 
-        uds.insert(KIO::UDSEntry::UDS_NAME, QLatin1String("."));
+        uds.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
         uds.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, i18n("All Tags"));
 
         statEntry(uds);
@@ -350,7 +349,7 @@ void TagsProtocol::mimetype(const QUrl& url)
 
     case RootUrl:
     case TagUrl:
-        mimeType(QLatin1String("inode/directory"));
+        mimeType(QStringLiteral("inode/directory"));
         finished();
         return;
 
